@@ -48,6 +48,45 @@ class Organization(ApiObject):
         )
         self.dirty_fields = {}
 
+    def create_repo(
+            self,
+            repoName: str,
+            description: str = "",
+            private: bool = False,
+            autoInit=True,
+            gitignores: str = None,
+            license: str = None,
+            readme: str = "Default",
+            issue_labels: str = None,
+            default_branch="master",
+    ):
+        """Create an organization Repository
+
+        Throws:
+            AlreadyExistsException: If the Repository exists already.
+            Exception: If something else went wrong.
+        """
+        result = self.gitea.requests_post(
+            f"/orgs/{self.name}/repos",
+            data={
+                "name": repoName,
+                "description": description,
+                "private": private,
+                "auto_init": autoInit,
+                "gitignores": gitignores,
+                "license": license,
+                "issue_labels": issue_labels,
+                "readme": readme,
+                "default_branch": default_branch,
+            },
+        )
+        if "id" in result:
+            self.gitea.logger.info("Successfully created Repository %s " % result["name"])
+        else:
+            self.gitea.logger.error(result["message"])
+            raise Exception("Repository not created... (gitea: %s)" % result["message"])
+        return Repository.parse_response(self, result)
+
     def get_repositories(self) -> List["Repository"]:
         results = self.gitea.requests_get_paginated(
             Organization.ORG_REPOS_REQUEST % self.username
@@ -175,6 +214,45 @@ class User(ApiObject):
         self.gitea.requests_patch(User.ADMIN_EDIT_USER.format(**args), data=values)
         self.dirty_fields = {}
 
+    def create_repo(
+            self,
+            repoName: str,
+            description: str = "",
+            private: bool = False,
+            autoInit=True,
+            gitignores: str = None,
+            license: str = None,
+            readme: str = "Default",
+            issue_labels: str = None,
+            default_branch="master",
+    ):
+        """Create a user Repository
+
+        Throws:
+            AlreadyExistsException: If the Repository exists already.
+            Exception: If something else went wrong.
+        """
+        result = self.gitea.requests_post(
+            "/user/repos",
+            data={
+                "name": repoName,
+                "description": description,
+                "private": private,
+                "auto_init": autoInit,
+                "gitignores": gitignores,
+                "license": license,
+                "issue_labels": issue_labels,
+                "readme": readme,
+                "default_branch": default_branch,
+            },
+        )
+        if "id" in result:
+            self.gitea.logger.info("Successfully created Repository %s " % result["name"])
+        else:
+            self.gitea.logger.error(result["message"])
+            raise Exception("Repository not created... (gitea: %s)" % result["message"])
+        return Repository.parse_response(self, result)
+
     def get_repositories(self) -> List["Repository"]:
         """ Get all Repositories owned by this User."""
         url = f"/users/{self.username}/repos"
@@ -189,7 +267,7 @@ class User(ApiObject):
 
     def get_teams(self) -> List['Team']:
         url = f"/user/teams"
-        results = self.gitea.requests_get(url, sudo=self)
+        results = self.gitea.requests_get_paginated(url, sudo=self)
         return [Team.parse_response(self.gitea, result) for result in results]
 
     def get_accessible_repos(self) -> List['Repository']:
@@ -253,8 +331,6 @@ class Repository(ApiObject):
     REPO_USER_TIME = """/repos/%s/%s/times/%s"""  # <owner>, <reponame>, <username>
     REPO_COMMITS = "/repos/%s/%s/commits"  # <owner>, <reponame>
     REPO_TRANSFER = "/repos/{owner}/{repo}/transfer"
-    REPO_CONTENTS = "/repos/{owner}/{repo}/contents"
-    REPO_CONTENT = """/repos/{owner}/{repo}/contents/{filepath}"""
     REPO_MILESTONES = """/repos/{owner}/{repo}/milestones"""
 
     def __init__(self, gitea):
@@ -443,16 +519,15 @@ class Repository(ApiObject):
 
     def get_git_content(self: str = None, commit: "Commit" = None) -> List["Content"]:
         """https://git.sopranium.de/api/swagger#/repository/repoGetContentsList"""
-        url = Repository.REPO_CONTENTS.format(owner=self.owner.username, repo=self.name)
-        data = {"ref": "HEAD" if commit is None else commit.sha}
+        url = f"/repos/{self.owner.username}/{self.name}/contents"
+        data = {"ref": commit.sha} if commit else {}
         result = [Content.parse_response(self.gitea, f) for f in self.gitea.requests_get(url, data)]
         return result
 
     def get_file_content(self, content: "Content", commit: "Commit" = None) -> Union[str, List["Content"]]:
         """https://git.sopranium.de/api/swagger#/repository/repoGetContents"""
-        url = Repository.REPO_CONTENT.format(owner=self.owner.username,
-                                             repo=self.name, filepath=content.path)
-        data = {"ref": "HEAD" if commit is None else commit.sha}
+        url = f"/repos/{self.owner.username}/{self.name}/contents/{content.path}"
+        data = {"ref": commit.sha} if commit else {}
         if content.type == Content.FILE:
             return self.gitea.requests_get(url, data)["content"]
         else:
